==> perforce-0.3.0.tgz: perforce-0.3.0/php_clientuser.h <==
/*
 * Perforce Extension for PHP
 *
 * Copyright 2004 Jon Parise <jon@php.net>.  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE. 
 */

/* $Header: //guest/Jon_Parise/api/php/php_perforce.h#3 $ */

#ifndef PHP_CLIENTUSER_H
#define PHP_CLIENTUSER_H

#include "clientapi.h"

class PHPClientUser : public ClientUser
{
public:
	virtual void InputData(StrBuf *strbuf, Error *e);
	virtual void HandleError(Error *err);
    virtual void Message(Error *err);
	virtual void OutputError(char *errBuf);
	virtual void OutputInfo(char level, char *data);
	virtual void OutputBinary(char *data, int length);
	virtual void OutputText(char *data, int length);
	virtual void OutputStat(StrDict *varList);
	virtual void Prompt(const StrPtr &msg, StrBuf &buf, int bufsiz, Error *e);
	virtual void ErrorPause(char *errBuf, Error *e);
	virtual void Edit(FileSys *f1, Error *e);
	virtual void Diff(FileSys *f1, FileSys *f2, int doPage, char *diffFlags,
					  Error *e);
	virtual void Merge(FileSys *base, FileSys *leg1, FileSys *leg2,
					   FileSys *result, Error *e);
	virtual void Help(char * const *help);

	zval *object;
};

#endif /* PHP_CLIENTUSER_H */

==> perforce-1.0.0.tgz: perforce-1.0.0/php_clientuser.h <==
/*
 * Perforce Extension for PHP
 *
 * Copyright 2004-2007 Jon Parise <jon@php.net>.  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE. 
 */

/* $Header: //guest/Jon_Parise/api/php/php_perforce.h#3 $ */

#ifndef PHP_CLIENTUSER_H
#define PHP_CLIENTUSER_H

#include "clientapi.h"

class PHPClientUser : public ClientUser
{
public:
	PHPClientUser(zval *object);
	virtual ~PHPClientUser();

	virtual void InputData(StrBuf *strbuf, Error *e);
	virtual void HandleError(Error *err);
	virtual void Message(Error *err);
	virtual void OutputError(const char *errBuf);
	virtual void OutputInfo(char level, const char *data);
	virtual void OutputBinary(const char *data, int length);
	virtual void OutputText(const char *data, int length);
	virtual void OutputStat(StrDict *varList);
	virtual void Prompt(const StrPtr &msg, StrBuf &buf, int bufsiz, Error *e);
	virtual void ErrorPause(char *errBuf, Error *e);
	virtual void Edit(FileSys *f1, Error *e);
	virtual void Diff(FileSys *f1, FileSys *f2, int doPage, char *diffFlags,
					  Error *e);
	virtual void Merge(FileSys *base, FileSys *leg1, FileSys *leg2,
					   FileSys *result, Error *e);
	virtual void Help(const char * const *help);

private:
	PHPClientUser(PHPClientUser&);
	PHPClientUser& operator=(PHPClientUser&);

	zval * const mpObject;
};

#endif /* PHP_CLIENTUSER_H */
